<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Korpo
 * @since Korpo 1.0.0
 */

if ( ! function_exists( 'korpo_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Korpo 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function korpo_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'korpo_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'korpo_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Korpo 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function korpo_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'korpo_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'korpo_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Korpo 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function korpo_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'korpo_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if about section is enabled.
 *
 * @since Korpo 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'korpo_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if service section is enabled.
 *
 * @since Korpo 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'korpo_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if project section is enabled.
 *
 * @since Korpo 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_is_project_section_enable( $control ) {
	return ( $control->manager->get_setting( 'korpo_theme_options[project_section_enable]' )->value() );
}

/**
 * Check if latest section is enabled.
 *
 * @since Korpo 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_is_latest_section_enable( $control ) {
	return ( $control->manager->get_setting( 'korpo_theme_options[latest_section_enable]' )->value() );
}

/**
 * Check if contact section is enabled.
 *
 * @since Korpo 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'korpo_theme_options[contact_section_enable]' )->value() );
}
