<?php
/**
 * Latest Section options
 *
 * @package Theme Palace
 * @subpackage Korpo
 * @since Korpo 1.0.0
 */

// Add Latest section
$wp_customize->add_section( 'korpo_latest_section', array(
	'title'             => esc_html__( 'Latest Posts','korpo' ),
	'description'       => esc_html__( 'Latest Section options.', 'korpo' ),
	'panel'             => 'korpo_front_page_panel',
) );

// Latest content enable control and setting
$wp_customize->add_setting( 'korpo_theme_options[latest_section_enable]', array(
	'default'			=> 	$options['latest_section_enable'],
	'sanitize_callback' => 'korpo_sanitize_switch_control',
) );

$wp_customize->add_control( new Korpo_Switch_Control( $wp_customize, 'korpo_theme_options[latest_section_enable]', array(
	'label'             => esc_html__( 'Latest Section Enable', 'korpo' ),
	'section'           => 'korpo_latest_section',
	'on_off_label' 		=> korpo_switch_options(),
) ) );

// Latest us title setting and control
$wp_customize->add_setting( 'korpo_theme_options[latest_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['latest_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_theme_options[latest_title]', array(
	'label'           	=> esc_html__( 'Title', 'korpo' ),
	'section'        	=> 'korpo_latest_section',
	'active_callback' 	=> 'korpo_is_latest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_theme_options[latest_title]', array(
		'selector'            => '#latest-posts .posts-section-wrapper .entry-container .section-header span.section-subtitle',
		'settings'            => 'korpo_theme_options[latest_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_latest_title_partial',
    ) );
}

// latest Section background setting and control.
$wp_customize->add_setting( 'korpo_theme_options[latest_image]', array(
	'default'           => $options['latest_image'],
	'sanitize_callback' => 'korpo_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'korpo_theme_options[latest_image]',
		array(
		'label'       		=> esc_html__( 'Select Background Image', 'korpo' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'korpo' ), 800, 800 ),
		'section'     		=> 'korpo_latest_section',
		'active_callback'	=> 'korpo_is_latest_section_enable',
) ) );

// recent posts description control and setting
$wp_customize->add_setting( 'korpo_theme_options[latest_content_recent]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Korpo_Note_Control( $wp_customize, 'korpo_theme_options[latest_content_recent]', array(
	'label'             => esc_html__( 'Display three recent posts.', 'korpo' ),
	'section'           => 'korpo_latest_section',
	'active_callback'	=> 'korpo_is_latest_section_enable',
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'korpo_theme_options[latest_exclude_category]', array(
	'sanitize_callback' => 'korpo_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Korpo_Dropdown_Category_Control( $wp_customize,'korpo_theme_options[latest_exclude_category]', array(
	'label'             => esc_html__( 'Exclude Categories', 'korpo' ),
	'description'      	=> esc_html__( 'Note: Press CTRL key and select multiple categories. Posts from selected categories will be excluded.', 'korpo' ),
	'section'           => 'korpo_latest_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'korpo_is_latest_section_enable'
) ) );